Random
------

Some convenience functions based on functions of the ``random`` [0]_ and
``itertools`` [1]_ module.

Combine random and itertools
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. py:currentmodule:: iteration_utilities._recipes._core

- :py:func:`random_combination`, return a random combination.
- :py:func:`random_permutation`, return a random permutation.
- :py:func:`random_product`, return a random value from each iterable.


References
~~~~~~~~~~

.. [0] https://docs.python.org/library/random.html
.. [1] https://docs.python.org/library/itertools.html
